@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client;
-$BZ::Client::VERSION = '2.0_5';
+$BZ::Client::VERSION = '2.0_6';
 use BZ::Client::XMLRPC;
 use BZ::Client::Exception;
 use HTTP::CookieJar;
@@ -121,7 +121,9 @@ sub xmlrpc {
         if ( !$xmlrpc ) {
             my $url = $self->url()
               || $self->error('The Bugzilla servers URL is not set.');
-            $xmlrpc = BZ::Client::XMLRPC->new( 'url' => $url );
+            $xmlrpc = BZ::Client::XMLRPC->new(
+                    url     => $url,
+                    connect => $self->{'connect'} );
             $xmlrpc->logDirectory( $self->logDirectory() );
             $xmlrpc->logger( $self->logger() );
             $self->xmlrpc($xmlrpc);
@@ -265,7 +267,7 @@ BZ::Client - A client for the Bugzilla web services API.
 
 =head1 VERSION
 
-version 2.0_5
+version 2.0_6
 
 =head1 SYNOPSIS
 
@@ -290,7 +292,7 @@ USE THE 1.x SERIES UNLESS YOU PREFER DEBUGGING TO GETTING THINGS DONE.
 
 This section lists the class methods of BZ::Client.
 
-=head1 new
+=head2 new
 
   my $client = BZ::Client->new( url      => $url,
                                 user     => $user,
@@ -307,6 +309,8 @@ For debugging, you can pass in a subref named I<logger> which will be
 fed debugging information as the client works. Also the I<logDirectory>
 option is a directory where the raw http content will be dumped.
 
+=head3 Parameters
+
 =over
 
 =item url
@@ -363,6 +367,31 @@ a loadbalanced forward proxy.
 
 Default: 0
 
+=item connect
+
+A hashref with options for L<HTTP::Tiny>, this is passed through so the
+bellow are for reference only:
+
+=over 4
+
+=item http_proxy, https_proxy, proxy
+
+Nominates a proxy for HTTP, HTTPS or both, respectively.
+
+You might also use C<$ENV{all_proxy}>, C<$ENV{http_proxy}>, C<$ENV{https_proxy}>
+or C<$ENV{all_proxy}>.
+
+=item timeout
+
+Request timeout in seconds (default is 60)
+
+=item verify_SSL
+
+A boolean that indicates whether to validate the SSL certificate of an
+"https" connection (default is false)
+
+=back
+
 =back
 
 =head1 INSTANCE METHODS
@@ -372,23 +401,23 @@ perform.
 
 =head2 url
 
-  my $url = $client->url();
-  $client->url( $url );
+ $url = $client->url();
+ $client->url( $url );
 
 Returns or sets the Bugzilla servers URL.
 
 =head2 user
 
-  my $user = $client->user();
-  $client->user( $user );
+ $user = $client->user();
+ $client->user( $user );
 
 Returns or sets the user name to use when logging in to the Bugzilla
 server. Typically, this will be your email address.
 
 =head2 password
 
-  my $password = $client->password();
-  $client->password( $password );
+ $password = $client->password();
+ $client->password( $password );
 
 Returns or sets the password to use when logging in to the Bugzilla server.
 
@@ -415,31 +444,31 @@ Deletes local cookies and calls bugzilla's logout function
 
 Sets or gets the logging function. Argument is a coderef. Returns undef if none.
 
-  my $logger = $client->logger();
+ $logger = $client->logger();
 
-  $client->logger(
-      sub {
-          my ($level, $msg) = @_;
-          print STDERR "$level $message\n";
-          return 1
-      });
+ $client->logger(
+     sub {
+         my ($level, $msg) = @_;
+         print STDERR "$level $message\n";
+         return 1
+     });
 
 Also can be set via new(), e.g.
 
-  $client = BZ::Client->new( logger => sub { },
-                             url    => $url
-                             user   => $user,
-                             password => $password );
+ $client = BZ::Client->new( logger => sub { },
+                            url    => $url
+                            user   => $user,
+                            password => $password );
 
 =head2 log
 
-  $client->log( $level, $message );
+ $client->log( $level, $message );
 
 Sends log messages to whatever is loaded via I<logger>.
 
 =head2 api_call
 
-  my $response = $client->api_call( $methodName, $params );
+ $response = $client->api_call( $methodName, $params );
 
 Used by subclasses of L<BZ::Client::API> to invoke methods of the Bugzilla
 API. Takes a method name and a hash ref of parameters as input. Returns a
