@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Bug;
-$BZ::Client::Bug::VERSION = '2.0_5';
+$BZ::Client::Bug::VERSION = '2.0_6';
 use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Bug.html
@@ -335,7 +335,7 @@ BZ::Client::Bug - Client side representation of a bug in Bugzilla
 
 =head1 VERSION
 
-version 2.0_5
+version 2.0_6
 
 =head1 SYNOPSIS
 
@@ -434,8 +434,8 @@ These deal with bug-related information, but not bugs directly.
 
 =head2 fields
 
-  $fields = BZ::Client::Bug->fields( $client, $params )
-  @fields = BZ::Client::Bug->fields( $client, $params )
+ $fields = BZ::Client::Bug->fields( $client, $params )
+ @fields = BZ::Client::Bug->fields( $client, $params )
 
 Get information about valid bug fields, including the lists of legal values for each field.
 
@@ -609,8 +609,8 @@ You specified an invalid field name or id.
 
 =head2 legal_values
 
-  $values = BZ::Client::Bug->legal_values( $client, $field )
-  @values = BZ::Client::Bug->legal_values( $client, $field )
+ $values = BZ::Client::Bug->legal_values( $client, $field )
+ @values = BZ::Client::Bug->legal_values( $client, $field )
 
 Tells you what values are allowed for a particular field.
 
@@ -662,8 +662,8 @@ Listed here in order of what you most likely want to do... maybe?
 
 =head2 get
 
-  $bugs = BZ::Client::Bug->get( $client, \%params );
-  @bugs = BZ::Client::Bug->get( $client, \%params );
+ @bugs = BZ::Client::Bug->get( $client, \%params );
+ $bugs = BZ::Client::Bug->get( $client, \%params );
 
 Gets information about particular bugs in the database.
 
@@ -717,8 +717,8 @@ You do not have access to the bug_id you specified.
 
 =head2 search
 
-  my $bugs = BZ::Client::Bug->search( $client, \%params );
-  my @bugs = BZ::Client::Bug->search( $client, \%params );
+ @bugs = BZ::Client::Bug->search( $client, \%params );
+ $bugs = BZ::Client::Bug->search( $client, \%params );
 
 Searches for bugs matching the given parameters.
 
@@ -728,8 +728,8 @@ See L<INSTANCE METHODS> for how to use them.
 
 =head2 history
 
-  $history = BZ::Client::Bug->history( $client, \%params );
-  @history = BZ::Client::Bug->history( $client, \%params );
+ @history = BZ::Client::Bug->history( $client, \%params );
+ $history = BZ::Client::Bug->history( $client, \%params );
 
 Gets the history of changes for particular bugs in the database.
 
@@ -809,8 +809,8 @@ The same as L</get>.
 
 =head2 possible_duplicates
 
-  $bugs = BZ::Client::Bug->possible_duplicates( $client, \%params );
-  @bugs = BZ::Client::Bug->possible_duplicates( $client, \%params );
+ @bugs = BZ::Client::Bug->possible_duplicates( $client, \%params );
+ $bugs = BZ::Client::Bug->possible_duplicates( $client, \%params );
 
 Allows a user to find possible duplicate bugs based on a set of keywords such as a user may use as a bug summary. Optionally the search can be narrowed down to specific products.
 
@@ -870,8 +870,8 @@ FIXME more details needed
 
 =head2 update_see_also
 
-  $changes = BZ::Client::Bug->update_see_also( $client, \%params );
-  @changes = BZ::Client::Bug->update_see_also( $client, \%params );
+ @changes = BZ::Client::Bug->update_see_also( $client, \%params );
+ $changes = BZ::Client::Bug->update_see_also( $client, \%params );
 
 Adds or removes URLs for the I<See Also> field on bugs. These URLs must point to some valid bug in some Bugzilla installation or in Launchpad.
 
@@ -915,20 +915,20 @@ These are arrays of strings, representing the actual changes that were made to t
 
 Here's a diagram of what the return value looks like for updating bug ids 1 and 2:
 
-    {
-        1 => {
-            see_also => {
-                added   => [(an array of bug URLs)],
-                removed => [(an array of bug URLs)],
-            }
-        },
-        2 => {
-            see_also => {
-                added   => [(an array of bug URLs)],
-                removed => [(an array of bug URLs)],
-            }
-        }
-    }
+ {
+     1 => {
+         see_also => {
+             added   => [(an array of bug URLs)],
+             removed => [(an array of bug URLs)],
+         }
+     },
+     2 => {
+         see_also => {
+             added   => [(an array of bug URLs)],
+             removed => [(an array of bug URLs)],
+         }
+     }
+ }
 
 This return value allows you to tell what this method actually did.
 
@@ -958,8 +958,8 @@ Before Bugzilla 3.6, error 115 had a generic error code of 32000.
 
 =head2 update_tags
 
-  $changes = BZ::Client::Bug->update_tags( $client, \%params );
-  @changes = BZ::Client::Bug->update_tags( $client, \%params );
+ @changes = BZ::Client::Bug->update_tags( $client, \%params );
+ $changes = BZ::Client::Bug->update_tags( $client, \%params );
 
 Adds or removes tags on bugs.
 
@@ -1007,20 +1007,20 @@ These are arrays of strings, representing the actual changes that were made to t
 
 Here's a diagram of what the return value looks like for updating bug ids 1 and 2:
 
-    {
-        1 => {
-            tags => {
-                added   => [(an array of tags)],
-                removed => [(an array of tags)],
-            }
-        },
-        2 => {
-            tags => {
-                added   => [(an array of tags)],
-                removed => [(an array of tags)],
-            }
-        }
-    }
+ {
+     1 => {
+         tags => {
+             added   => [(an array of tags)],
+             removed => [(an array of tags)],
+         }
+     },
+     2 => {
+         tags => {
+             added   => [(an array of tags)],
+             removed => [(an array of tags)],
+         }
+     }
+ }
 
 This return value allows you to tell what this method actually did.
 
@@ -1030,7 +1030,7 @@ This method can throw all of the errors that L</get> throws.
 
 =head2 new
 
-  my $bug = BZ::Client::Bug->new( id => $id );
+ my $bug = BZ::Client::Bug->new( id => $id );
 
 Creates a new bug object instance with the given ID.
 
@@ -1046,102 +1046,102 @@ Once you have a bug object, you can use these methods to inspect and manipulate
 
 =head2 id
 
-  my $id = $bug->id();
-  $bug->id( $id );
+ $id = $bug->id();
+ $bug->id( $id );
 
 Gets or sets the bugs ID.
 
 =head2 alias
 
-  my $alias = $bug->alias();
-  $bug->alias( $alias );
+ $alias = $bug->alias();
+ $bug->alias( $alias );
 
 Gets or sets the bugs alias. If there is no alias or aliases are disabled in Bugzilla,
 this will be an empty string.
 
 =head2 assigned_to
 
-  my $assigned_to = $bug->assigned_to();
-  $bug->assigned_to( $assigned_to );
+ $assigned_to = $bug->assigned_to();
+ $bug->assigned_to( $assigned_to );
 
 Gets or sets the login name of the user to whom the bug is assigned.
 
 =head2 component
 
-  my $component = $bug->component();
-  $bug->component( $component );
+ $component = $bug->component();
+ $bug->component( $component );
 
 Gets or sets the name of the current component of this bug.
 
 =head2 creation_time
 
-  my $dateTime = $bug->creation_time();
-  $bug->creation_time( $dateTime );
+ $dateTime = $bug->creation_time();
+ $bug->creation_time( $dateTime );
 
 Gets or sets the date and time, when the bug was created.
 
 =head2 dupe_of
 
-  my $dupeOf = $bug->dupe_of();
-  $bug->dupe_of( $dupeOf );
+ $dupeOf = $bug->dupe_of();
+ $bug->dupe_of( $dupeOf );
 
 Gets or sets the bug ID of the bug that this bug is a duplicate of. If this
 bug isn't a duplicate of any bug, this will be an empty int.
 
 =head2 is_open
 
-  my $isOpen = $bug->is_open();
-  $bug->is_open( $isOpen );
+ $isOpen = $bug->is_open();
+ $bug->is_open( $isOpen );
 
 Gets or sets, whether this bug is closed. The return value, or parameter value
 is true (1) if this bug is open, false (0) if it is closed.
 
 =head2 last_change_time
 
-  my $lastChangeTime = $bug->last_change_time();
-  $bug->last_change_time( $lastChangeTime );
+ $lastChangeTime = $bug->last_change_time();
+ $bug->last_change_time( $lastChangeTime );
 
 Gets or sets the date and time, when the bug was last changed.
 
 =head2 priority
 
-  my $priority = $bug->priority();
-  $bug->priority( $priority );
+ $priority = $bug->priority();
+ $bug->priority( $priority );
 
 Gets or sets the priority of the bug.
 
 =head2 product
 
-  my $product = $bug->product();
-  $bug->product( $product );
+ $product = $bug->product();
+ $bug->product( $product );
 
 Gets or sets the name of the product this bug is in.
 
 =head2 resolution
 
-  my $resolution = $bug->resolution();
-  $bug->resolution( $resolution );
+ $resolution = $bug->resolution();
+ $bug->resolution( $resolution );
 
 Gets or sets the current resolution of the bug, or an empty string if the bug is open.
 
 =head2 severity
 
-  my $severity = $bug->severity();
-  $bug->severity( $severity );
+ $severity = $bug->severity();
+ $bug->severity( $severity );
 
 Gets or sets the current severity of the bug.
 
 =head2 status
 
-  my $status = $bug->status();
-  $bug->status( $status );
+ $status = $bug->status();
+ $bug->status( $status );
 
 Gets or sets the current status of the bug.
 
 =head2 summary
 
-  my $summary = $bug->summary();
-  $bug->summary( $summary );
+ $summary = $bug->summary();
+ $bug->summary( $summary );
 
 Gets or sets the summary of this bug.
 
