@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC;
-$BZ::Client::XMLRPC::VERSION = '2.0_5';
+$BZ::Client::XMLRPC::VERSION = '2.0_6';
 use URI;
 use Encode;
 use XML::Writer;
@@ -49,8 +49,12 @@ sub web_agent {
     }
     else {
         my $wa = $self->{'web_agent'};
+        my $connect = $self->{'connect'} || {};
+        $self->error(q/'connect' parameter in new() not a hashref/)
+            unless ref $connect eq 'HASH';
         if (!defined($wa)) {
             $wa = HTTP::Tiny->new(
+                %$connect,
                 agent => 'BZ::Client::XMLRPC ' . $BZ::Client::XMLRPC::VERSION
             );
             $self->web_agent($wa);
@@ -246,16 +250,17 @@ sub _get_response {
         }
     }
     if (!$res->{success}) {
-        my $msg = $res->{reason};
         my $code = $res->{status};
         if ($code == 401) {
-           $self->error('Authorization error, perhaps invalid user name and/or password', $code);
+            $self->error('Authorization error, perhaps invalid user name and/or password', $code);
         }
         elsif ($code == 404) {
-           $self->error('Bugzilla server not found, perhaps invalid URL.', $code);
+            $self->error('Bugzilla server not found, perhaps invalid URL.', $code);
         }
         else {
-           $self->error("Unknown error: $msg", $code);
+            my $msg = $res->{reason};
+            $msg .= ' : ' . $res->{content} if $res->{content};
+            $self->error("Unknown error: $msg", $code);
         }
     }
 
@@ -312,14 +317,14 @@ sub logDirectory {
 }
 
 package BZ::Client::XMLRPC::int;
-$BZ::Client::XMLRPC::int::VERSION = '2.0_5';
+$BZ::Client::XMLRPC::int::VERSION = '2.0_6';
 sub new {
     my($class, $value) = @_;
     return bless(\$value, (ref($class) || $class))
 }
 
 package BZ::Client::XMLRPC::boolean;
-$BZ::Client::XMLRPC::boolean::VERSION = '2.0_5';
+$BZ::Client::XMLRPC::boolean::VERSION = '2.0_6';
 sub new {
     my($class, $value) = @_;
     return bless(\$value, (ref($class) || $class))
@@ -336,7 +341,7 @@ sub FALSE { $false }
 }
 
 package BZ::Client::XMLRPC::double;
-$BZ::Client::XMLRPC::double::VERSION = '2.0_5';
+$BZ::Client::XMLRPC::double::VERSION = '2.0_6';
 sub new {
     my($class, $value) = @_;
     return bless(\$value, (ref($class) || $class))
@@ -356,7 +361,7 @@ BZ::Client::XMLRPC - Performs XML-RPC calls on behalf of the client.
 
 =head1 VERSION
 
-version 2.0_5
+version 2.0_6
 
 =head1 SYNOPSIS
 
